@@ -4,7 +4,9 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '1.0.4.0';
+our $VERSION = '1.0.7.0';
+
+use Exporter 'import';
 
 use Search::Xapian::Database;
 use Search::Xapian::Document;
@@ -12,6 +14,7 @@ use Search::Xapian::ESet;
 use Search::Xapian::ESetIterator;
 use Search::Xapian::MSet;
 use Search::Xapian::MSetIterator;
+use Search::Xapian::MultiValueSorter;
 use Search::Xapian::PositionIterator;
 use Search::Xapian::PostingIterator;
 use Search::Xapian::Query;
@@ -30,12 +33,11 @@ use Search::Xapian::TradWeight;
 use Search::Xapian::SimpleStopper;
 use Search::Xapian::PerlStopper;
 
-require Exporter;
 require DynaLoader;
 
-our @ISA = qw(Exporter DynaLoader);
+our @ISA = qw(DynaLoader);
 
-# Items to export into callers namespace by default. Note: do not export
+# Items to export into caller's namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
 # Do not simply export all your public functions/methods/constants.
 
@@ -53,7 +55,10 @@ our %EXPORT_TAGS = (
                                   OP_NEAR
                                   OP_PHRASE
 				  OP_VALUE_RANGE
+				  OP_SCALE_WEIGHT
                                   OP_ELITE_SET
+				  OP_VALUE_GE
+				  OP_VALUE_LE
                                  ) ],
                     'db' => [ qw(
                                  DB_OPEN
@@ -74,6 +79,10 @@ our %EXPORT_TAGS = (
 				 FLAG_WILDCARD
 				 FLAG_PURE_NOT
 				 FLAG_PARTIAL
+				 FLAG_SPELLING_CORRECTION
+				 FLAG_SYNONYM
+				 FLAG_AUTO_SYNONYMS
+				 FLAG_AUTO_MULTIWORD_SYNONYMS
                                  ) ],
                     'qpstem' => [ qw(
 				 STEM_NONE
@@ -102,7 +111,7 @@ foreach (@{ $EXPORT_TAGS{'ops'} }) {
 }
 
 our @DB_NAMES;
-foreach (@{ $EXPORT_TAGS{'dbs'} }) {
+foreach (@{ $EXPORT_TAGS{'db'} }) {
   $DB_NAMES[eval $_] = $_;
 }
 
@@ -151,7 +160,7 @@ more 'perlish' interface to some common operations, as demonstrated above.
 
 There are some gaps in the POD documentation for wrapped classes, but you
 can read the Xapian C++ API documentation at
-L<http://www.xapian.org/docs/apidoc/html/annotated.html> for details of
+L<http://xapian.org/docs/apidoc/html/annotated.html> for details of
 these.  Alternatively, take a look at the code in the examples and tests.
 
 If you want to use Search::Xapian and the threads module together, make
@@ -162,7 +171,7 @@ destroyed more than once.
 
 If you encounter problems, or have any comments, suggestions, patches, etc
 please email the Xapian-discuss mailing list (details of which can be found at
-L<http://www.xapian.org/lists.php>).
+L<http://xapian.org/lists>).
 
 =head2 EXPORT
 
@@ -281,6 +290,14 @@ final word as a wildcarded match, unless it is followed by
 whitespace, to produce more stable results from interactive
 searches.
 
+=item FLAG_SPELLING_CORRECTION
+
+=item FLAG_SYNONYM
+
+=item FLAG_AUTO_SYNONYMS
+
+=item FLAG_AUTO_MULTIWORD_SYNONYMS
+
 =back
 
 =head1 :qpstem
@@ -297,8 +314,8 @@ Don't stem any terms.
 
 =item STEM_SOME
 
-Stem some terms, in a manner compatible with Omega (capitalised words aren't
-stemmed, and get an 'R' prefix).
+Stem some terms, in a manner compatible with Omega (capitalised words and those
+in phrases aren't stemmed).
 
 =back
 
@@ -373,6 +390,10 @@ advice, bugfixes, and wrapper code for the more obscure classes.
 
 Alex Bowley E<lt>kilinrax@cpan.orgE<gt>
 
+Please report any bugs/suggestions to E<lt>xapian-discuss@lists.xapian.orgE<gt>
+or use the Xapian bug tracker L<http://xapian.org/bugs>.  Please do
+NOT use the CPAN bug tracker or mail any of the authors individually.
+
 =head1 SEE ALSO
 
 L<Search::Xapian::BM25Weight>,
@@ -380,6 +401,7 @@ L<Search::Xapian::BoolWeight>,
 L<Search::Xapian::Database>,
 L<Search::Xapian::Document>,
 L<Search::Xapian::Enquire>,
+L<Search::Xapian::MultiValueSorter>,
 L<Search::Xapian::PositionIterator>,
 L<Search::Xapian::PostingIterator>,
 L<Search::Xapian::QueryParser>,
@@ -391,6 +413,6 @@ L<Search::Xapian::ValueIterator>,
 L<Search::Xapian::Weight>,
 L<Search::Xapian::WritableDatabase>,
 and
-L<http://www.xapian.org/>.
+L<http://xapian.org/>.
 
 =cut
